@@ -51,11 +51,6 @@ class Application(tornado.web.Application):
         if 'static_path' in settings:
             settings['static_path'] = self.root_dir + '/' + settings['static_path'].lstrip('/')
 
-        if 'database' in settings and isinstance(settings['database'], dict):
-            if 'debug' in settings['database']:
-                Connection.set_debug(settings['database']['debug'])
-            Connection.set_engine(settings['database'])
-
         if 'ui_methods' in settings:
             if isinstance(settings['ui_methods'], list):
                 for i, ui_method in enumerate(settings['ui_methods']):
@@ -80,6 +75,13 @@ class Application(tornado.web.Application):
         tornado.ioloop.IOLoop.instance().start()
 
     def load_database(self):
+        if not Connection.engine:
+            if 'database' in self.settings and isinstance(self.settings['database'], dict):
+                if 'debug' in self.settings['database']:
+                    Connection.set_debug(self.settings['database']['debug'])
+                Connection.set_engine(self.settings['database'])
+            else:
+                return None
         return Connection.create()
 
 class ViewData(object):
